import { NextAuthOptions } from "next-auth";
import CredentialsProvider from "next-auth/providers/credentials";
import { signInWithCredentials } from "./actions/auth.actions";

export const nextauthOptions: NextAuthOptions = {
  secret: process.env.NEXTAUTH_SECRET,
  providers: [
    CredentialsProvider({
      name: "Credentials",
      credentials: {
        email: { label: "Email", type: "email", required: true },
        password: { label: "Password", type: "password", required: true },
      },
      async authorize(credentials) {
        if (!credentials?.email || !credentials?.password) {
          return null;
        }

        const response = await signInWithCredentials({
          email: credentials?.email,
          password: credentials?.password,
        });

        const user = {
          ...response.user,
          roles: response.roles,
          permissions: response.permissions,
          token: response.token,
          assignmentStatus: response.assignmentStatus,
          batchStatuses: response.batchStatuses,
          locationStatuses: response.locationStatuses,
          projects: response.projects,
          currentProjectId: response.currentProjectId,
          currentProject: response.currentProject,
        };

        return user;
      },
    }),
  ],
  callbacks: {
    async signIn() {
      return true;
    },
    async jwt({ token, user, trigger, session }) {
      if (user) {
        token = {
          id: user.id,
          first_name: user.first_name,
          last_name: user.last_name,
          full_name: user.full_name,
          email: user.email,
          is_system_admin: user.is_system_admin,
          roles: user.roles,
          permissions: user.permissions,
          token: user.token,
          assignmentStatus: user.assignmentStatus,
          batchStatuses: user.batchStatuses,
          locationStatuses: user.locationStatuses,
          projects: user.projects,
          currentProjectId: user.currentProjectId,
          currentProject: user.currentProject,
        };
      }

      // Allow client to update `currentProjectId`
      if (trigger === "update" && session?.currentProjectId) {
        token.currentProjectId = session.currentProjectId;
      }

      return token;
    },
    async session({ session, token }) {
      return {
        ...session,
        user: {
          id: token.id,
          first_name: token.first_name,
          last_name: token.last_name,
          full_name: token.full_name,
          email: token.email,
          is_system_admin: token.is_system_admin,
          roles: token.roles,
          permissions: token.permissions,
          token: token.token,
        },
        currentProject: token.currentProject,
        currentProjectId: token.currentProjectId ?? "", // Include currentProjectId
        assignmentStatus: token.assignmentStatus,
        batchStatus: token.batchStatuses,
        locationStatus: token.locationStatuses,
        projects: token.projects,
      };
    },
  },
};
